// Copyright 2023 Georges Racinet <georges.racinet@octobus.net>
//
// This software may be used and distributed according to the terms of the
// GNU General Public License version 2 or any later version.
// SPDX-License-Identifier: GPL-2.0-or-later
//! Common utilities
use std::io;

/// Convert `NotFound` I/O error to `None`
///
/// To be used when a file missing is logically equivalent to empty high level contents.
pub fn io_error_not_found_as_none<T>(res: io::Result<T>) -> io::Result<Option<T>> {
    match res {
        Ok(t) => Ok(Some(t)),
        Err(e) => {
            if e.kind() == io::ErrorKind::NotFound {
                Ok(None)
            } else {
                Err(e)
            }
        }
    }
}
